module Debate.Gibberish.Domains.Epistemology exposing (..)

import Debate.Gibberish.Helpers exposing (gibberishTitle)
import Debate.Gibberish.Types exposing (..)


epistemologyGibberish : Gibberish
epistemologyGibberish =
    let
        name =
            "Epistemology"
    in
    { gibberishTitle = name
    , gibberishImage = formatName name
    , gibberishTerms =
        [ { term = "abductive arguments"
          , explanation = SpecificExplanation "In a formal sense, I take an argument to be logical construct whereby the outputs consistently follow from an input, or set of inputs, according to a formal system of internally consistent rules or laws. Traditionally, abductive arguments are taken to fall outside this scope, so on my interpretation, the term \"abductive argument\" is probably gibberish."
          }
        , { term = "content internalism"
          , explanation = NoClue
          }
        , { term = "direct reference"
          , explanation = SpecificExplanation "I don't understand the term usage as it's been used and unpacked in conversation. I don't understand what it means for a word to \"point to\" an object, and I also don't understand what semantic advantage or distinction this has to a mundane, ostensibly non-direct reference to an object in speech."
          }
        , { term = "externalist epistemology"
          , explanation = SpecificExplanation "I don't take anything other than logic to be justification-giving. As such, any position that claims that justification can arrive through non-inferential means, such as mechanisms operating outside the mind, just sounds like gibberish."
          }
        , { term = "inductive arguments"
          , explanation = SpecificExplanation "In a formal sense, I take an argument to be logical construct whereby the outputs consistently follow from an input, or set of inputs, according to a formal system of internally consistent rules or laws. Traditionally, inductive arguments are taken to fall outside this scope, so on my interpretation, the term \"inductive argument\" is probably gibberish."
          }
        , { term = "non-entailing explanations"
          , explanation = SpecificExplanation "I take an explanation to be a set of premises that lead to a conclusion, so the term just sounds like some sort of contradiction."
          }
        , { term = "non-inferential justification"
          , explanation = SpecificExplanation "I don't take anything other than logic to be justification-giving. As such, any position that claims that justification can arrive through non-inferential means just sounds like gibberish."
          }
        , { term = "phenomenal conservatism"
          , explanation = SpecificExplanation "I don't take anything other than logic to be justification-giving. As such, any position that claims that justification can arrive through non-inferential means, such as merely having a seeming, just sounds like gibberish."
          }
        , { term = "synthetic a priori"
          , explanation = SpecificExplanation "I take a priori arguments to be arguments based on principles or axioms and not based on experience, which would seem to place a priori outside the purview of syntheticity."
          }
        , { term = "ultimate grounding"
          , explanation = SpecificExplanation "It's completely unclear what this theo-babble is meant to communicate. I assume it has something to do with the absence of antecedent conditions and/or irreducibility that provide some sort of \"best epistemology\" or something, but I can't be sure. It just sounds like gobbledy"
          }
        ]
    }
